@@ -30,7 +30,6 @@ from msaBase.models.middlewares import MiddlewareTypes
 from msaBase.models.sysinfo import MSASystemGPUInfo, MSASystemInfo
 from msaBase.sysinfo import get_sysgpuinfo, get_sysinfo
 from msaBase.utils.constants import PUBSUB_NAME, REGISTRY_TOPIC, SERVICE_TOPIC
-from msaDocModels import health
 from msaDocModels.health import MSAHealthDefinition, MSAHealthMessage
 from msaDocModels.openapi import MSAOpenAPIInfo
 from msaDocModels.scheduler import MSASchedulerStatus, MSASchedulerTaskDetail, MSASchedulerTaskStatus
@@ -44,7 +43,7 @@ from starlette.responses import HTMLResponse, JSONResponse, Response
 from starlette_context import plugins
 
 
-def getSecretKey() -> str:
+def get_secret_key() -> str:
     """
     Get Secret Key for Token creation from OS Environment Variable **SECRET_KEY_TOKEN**
 
@@ -59,7 +58,7 @@ def getSecretKey() -> str:
     return key
 
 
-def getSecretKeySessions() -> str:
+def get_secret_key_sessions() -> str:
     """
     Get Secret Key for Session Middleware from OS Environment Variable **SECRET_KEY_SESSIONS**
 
@@ -74,7 +73,7 @@ def getSecretKeySessions() -> str:
     return key
 
 
-def getSecretKeyCSRF() -> str:
+def get_secret_key_csrf() -> str:
     """
     Get Secret Key for CSRF Middleware from OS Environment Variable **SECRET_KEY_CSRF**
 
@@ -203,6 +202,7 @@ class MSAApp(FastAPI):
             except Exception as ex:
                 self.logger.info(ex)
 
+    @staticmethod
     def uses_temporary_config(function):
         """
         Makes an endpoint use one-time config whenever it is present.
@@ -238,7 +238,7 @@ class MSAApp(FastAPI):
                 client.publish_event(
                     pubsub_name=PUBSUB_NAME,
                     topic_name=topic_name,
-                    data=f"[{service_name if service_name else self.title}]: " + message,
+                    data=f"[{service_name}]: " + message if service_name else message,
                     data_content_type="application/json",
                 )
         self.logger.info(message)
@@ -781,14 +781,14 @@ class MSAApp(FastAPI):
         self.logger.info("Add Middleware CSRF")
         from starlette_wtf import CSRFProtectMiddleware
 
-        self.add_middleware(CSRFProtectMiddleware, csrf_secret=getSecretKeyCSRF())
+        self.add_middleware(CSRFProtectMiddleware, csrf_secret=get_secret_key_csrf())
 
     def configure_session_middleware(self) -> None:
         """Add Middleware Session"""
         self.logger.info("Add Middleware Session")
         from starlette.middleware.sessions import SessionMiddleware
 
-        self.add_middleware(SessionMiddleware, secret_key=getSecretKeySessions())
+        self.add_middleware(SessionMiddleware, secret_key=get_secret_key_sessions())
 
     def configure_background_scheduler(self) -> None:
         """Add Background Scheduler"""
