@@ -1,5 +1,7 @@
 from typing import Any, Dict, List, Union
 
+from msaDocModels.sdu import SDUPage
+
 
 def convert_list_to_str(input_list: List) -> str:
     """
@@ -41,3 +43,24 @@ def get_one_string_text(input_text: Union[str, List[str], Dict[Any, str]]):
     elif type_input_text == dict:
         input_text = convert_dict_to_str(input_dict=input_text)
     return input_text.replace("/n", " ").replace('"', "'")
+
+
+async def get_all_sentences(text_pages: List[SDUPage]) -> Dict[int, List[str]]:
+    """
+    Extracts all sentences from a list of text pages.
+
+    Parameters:
+
+        text_pages: A list of SDUPage objects representing text pages.
+
+    Returns:
+
+        A dictionary where the keys are page IDs and the values are lists of sentences from the corresponding page.
+    """
+    sentences: Dict[int, List[str]] = {}
+    for page in text_pages:
+        sentences[page.id] = []
+        for par in page.text.paragraphs:
+            for sen in par.sentences:
+                sentences[page.id].append(sen.text)
+    return sentences
