@@ -2,32 +2,39 @@ import enum
 
 
 class MiddlewareTypes(enum.Enum):
+    """
+    Types of middlewares and whether they require a service reload when changed.
+
+    Attributes:
+        profiler: Profiler Middleware.
+        validationception: ValidationError Middleware.
+        httpception: HTTPException Middleware.
+        starception: Starception Middleware.
+        cors: CORS Middleware.
+        httpsredirect: HTTPSRedirect Middleware.
+        gzip: GZip Middleware.
+        session: Session Middleware.
+        csrf: CSRF Middleware.
+        msgpack: MSGPack Middleware.
+        context: Context Middleware.
+        timing: Timing Middleware.
+        limiter: Handler Middleware.
+    """
+
     profiler = ("Middleware Profiler", True)
-    """Profiler Middleware."""
     validationception = ("Handler ValidationError", True)
-    """ValidationError Middleware."""
     httpception = ("Handler HTTPException", True)
-    """HTTPException Middleware."""
     starception = ("Middleware Starception", True)
-    """Starception Middleware."""
     cors = ("Middleware CORS", True)
-    """CORS Middleware."""
     httpsredirect = ("Middleware HTTPSRedirect", True)
-    """HTTPSRedirect Middleware."""
     gzip = ("Middleware GZip", True)
-    """GZip Middleware."""
     session = ("Middleware Session", True)
-    """Session Middleware."""
     csrf = ("Middleware CSRF", True)
-    """CSRF Middleware."""
     msgpack = ("Middleware MSGPack", True)
-    """MSGPack Middleware."""
     context = ("Middleware Context", True)
-    """Context Middleware."""
     timing = ("Middleware Timing", True)
-    """Timing Middleware."""
     limiter = ("Limiter Handler", True)
-    """Handler Middleware."""
+    """"""
 
     def __init__(self, readable_name: str, need_restart: bool):
         self.readable_name = readable_name
